@@ -74,6 +74,7 @@ func NewRootCommand() *cobra.Command {
 			// Create a new Cmd to provide shared dependencies and start components
 			log.Info("setting up manager")
 			mgr, err := manager.New(cfg, manager.Options{
+				MetricsBindAddress:      ":2112",
 				LeaderElection:          true,
 				LeaderElectionNamespace: minterv1.CloudCredOperatorNamespace,
 				LeaderElectionID:        leaderElectionConfigMap,
@@ -99,7 +100,8 @@ func NewRootCommand() *cobra.Command {
 
 			// Setup all Controllers
 			log.Info("setting up controller")
-			if err := controller.AddToManager(mgr); err != nil {
+			kubeconfigCommandLinePath := cmd.PersistentFlags().Lookup("kubeconfig").Value.String()
+			if err := controller.AddToManager(mgr, kubeconfigCommandLinePath); err != nil {
 				log.Error(err, "unable to register controllers to the manager")
 				os.Exit(1)
 			}
@@ -141,6 +143,7 @@ func (writer glogWriter) Write(data []byte) (n int, err error) {
 func main() {
 	defer glog.Flush()
 	cmd := NewRootCommand()
+	cmd.AddCommand(newRenderCommand())
 	err := cmd.Execute()
 	if err != nil {
 		log.Fatal(err)
